Temperature time series from 35 weather stations from Canada. This dataset
is a classic one and was used in famous package fda. We have made a few
changes in this dataset.
Usage
data("datasetCanada")
Arguments
Format
A list with two entries: m_cood and m_data.
m_coord
a tibble with latitude, logitude and the name
of stations.
m_data
a tibble where each column is the time series from a
weather station.