Learn R Programming

geoFKF (version 0.1.1)

geo_fkf: Kriging method for Spatial Functional Data.

Description

geo_fkf implements the kriging method for spatial functional datasets.

Usage

geo_fkf(m_data, m_coord, new_loc, p, t = seq(from = -pi, to = pi, by = 0.01))

Value

a list with three entries: estimates, Theta and cov_params

estimates

the estimate curve

Theta

weights (matrices) of the linear combination

cov_params

estimate \(\sigma^2\), \(\phi\) and \(\rho\)

Arguments

m_data

a tibble where each column or variable is data from a station

m_coord

a tibble with two columns: latitude and longitude

new_loc

a tible with one observation, where the columns or variables are latitude and longitude

p

order in the Fourier Polynomial

t

a time series with values belonging to \([-\pi, \pi]\) to evaluate the estimate curve

Examples

Run this code
data("datasetCanada")

m_data <- as.matrix(datasetCanada$m_data)
m_coord <- as.matrix(datasetCanada$m_coord[, 1:2])
pos <- sample.int(nrow(m_coord), 1)
log_pos <- !(seq_len(nrow(m_coord)) %in% pos)
new_loc <- m_coord[pos, ]
m_coord <- m_coord[log_pos, ]
m_data <- m_data[, log_pos]

geo_fkf(m_data, m_coord, new_loc)

Run the code above in your browser using DataLab