Learn R Programming

geoFKF (version 0.1.1)

logLikMultiNorm: Log likelihood function for multivariate normal with spatial dependency.

Description

Log likelihood function for multivariate normal with spatial dependency.

Arguments

mCoef

coefficient matrix. Each column is the coefficient from a curve;

mDist

distance matris;

s2

variance from the covariance model;

phi

variance from the covariance model;

rho

variance from the covariance model;